/*
Module : K8055D.h
Purpose: Defines the standard C interface file for the K8055, K8055N, VM110 & VM110N USB 
         Experiment Interface boards from Velleman / Whadda.
History: PJN / 27-12-2015 1. Initial release

Copyright (c) 2023 by PJ Naughter (Web: www.naughter.com, Email: pjna@naughter.com)

All rights reserved.

Copyright / Usage Details:

You are allowed to include the source code in any product (commercial, shareware, freeware or otherwise)
when your product is released in binary form. You are allowed to modify the source code in any way you want
except you cannot modify the copyright details at the top of each module. If you want to distribute source
code with your application, then you are only allowed to distribute versions released by the author. This is
to maintain a single distribution point for the source code.

*/


////////////////////////// Macros / Defines ///////////////////////////////////

#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif //#if defined(_MSC_VER) && (_MSC_VER >= 1020)

#ifndef __K8055N_H__
#define __K8055N_H__

#ifdef K8055NDLL_EXPORTS
#define K8055DAPI __declspec(dllexport)
#else
#define K8055DAPI __declspec(dllimport)
#endif //#ifdef K8055NDLL_EXPORTS


////////////////////////// Declaration ////////////////////////////////////////

#ifdef __cplusplus
extern "C" {
#endif //#ifdef __cplusplus

K8055DAPI int WINAPI SearchDevices();
K8055DAPI int WINAPI SetCurrentDevice(_In_ int nCardNumber);
K8055DAPI int WINAPI OpenDevice(_In_ int nCardNumber);
K8055DAPI void WINAPI CloseDevice();
K8055DAPI int WINAPI ReadAnalogChannel(_In_ int nChannel);
K8055DAPI void WINAPI ReadAllAnalog(_Inout_ int* pData1, _Inout_ int* pData2);
K8055DAPI void WINAPI OutputAnalogChannel(_In_ int nChannel, _In_ int nData);
K8055DAPI void WINAPI OutputAllAnalog(_In_ int nData1, _In_ int nData2);
K8055DAPI void WINAPI ClearAnalogChannel(_In_ int nChannel);
K8055DAPI void WINAPI ClearAllAnalog();
K8055DAPI void WINAPI SetAnalogChannel(_In_ int nChannel);
K8055DAPI void WINAPI SetAllAnalog();
K8055DAPI void WINAPI WriteAllDigital(_In_ int nData);
K8055DAPI void WINAPI ClearDigitalChannel(_In_ int nChannel);
K8055DAPI void WINAPI ClearAllDigital();
K8055DAPI void WINAPI SetDigitalChannel(_In_ int nChannel);
K8055DAPI void WINAPI SetAllDigital();
K8055DAPI _Success_(return != FALSE) BOOL WINAPI ReadDigitalChannel(_In_ int nChannel);
K8055DAPI int WINAPI ReadAllDigital();
K8055DAPI int WINAPI ReadCounter(_In_ int nCounter);
K8055DAPI int WINAPI ReadCounter16(_In_ int nCounter);
K8055DAPI void WINAPI ReadAll(_Inout_updates_(8) BYTE* pData);
K8055DAPI void WINAPI ResetCounter(_In_ int nCounter);
K8055DAPI void WINAPI SetCounterDebounceTime(_In_ int nCounter, _In_ int nDebounceTime);
K8055DAPI _Success_(return != FALSE) BOOL WINAPI Connected();
K8055DAPI void WINAPI SetPWM(_In_ int nChannel, _In_ int nData, _In_ int nFrequency);
K8055DAPI void WINAPI ReadBackAnalogOut(_Inout_updates_(2) int* pBuffer);
K8055DAPI int WINAPI ReadBackDigitalOut();
K8055DAPI int WINAPI Version();
K8055DAPI int WINAPI CardVersion();

#ifdef __cplusplus
}
#endif //#ifdef __cplusplus


#endif //#ifndef __K8055D_H__
